Stan Math Library: stan/math/fwd/scal/fun/Phi.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
Phi.hpp File Reference
`#include <stan/math/fwd/core.hpp>`
`#include <stan/math/prim/scal/fun/Phi.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
fvar< T > | stan::math::Phi (const fvar< T > &x)

[ Stan Home Page ] © 2011–2016, Stan Development Team.